Justbases-GUI
=============

Purpose
-------
Graphical user interface for the justbases library. Allows a user to
experiment with options for displaying a rational number as a single value
in any base.
